@@ -15,6 +15,7 @@ from __future__ import annotations
 import abc
 import contextlib
 import copy
+import dataclasses
 import enum
 import functools
 import gettext
@@ -674,13 +675,14 @@ class DataChannel:
 
     def __init__(self, hardware_source: HardwareSource, index: int, channel_id: typing.Optional[str] = None,
                  name: typing.Optional[str] = None, src_channel_index: typing.Optional[int] = None,
-                 processor: typing.Optional[SumProcessor] = None) -> None:
+                 processor: typing.Optional[SumProcessor] = None, is_context: bool = False) -> None:
         self.__hardware_source = hardware_source
         self.__index = index
         self.__channel_id = channel_id
         self.__name = name
         self.__src_channel_index = src_channel_index
         self.__processor = processor
+        self.__is_context = is_context
         self.__start_count = 0
         self.__state: typing.Optional[str] = None
         self.__data_shape: typing.Optional[DataAndMetadata.ShapeType] = None
@@ -730,6 +732,10 @@ class DataChannel:
     def processor(self) -> typing.Optional[SumProcessor]:
         return self.__processor
 
+    @property
+    def is_context(self) -> bool:
+        return self.__is_context
+
     @property
     def data_and_metadata(self) -> typing.Optional[DataAndMetadata.DataAndMetadata]:
         return self.__data_and_metadata
@@ -841,6 +847,17 @@ class FrameParameters(typing.Protocol):
     def as_dict(self) -> typing.Dict[str, typing.Any]: ...
 
 
+class AcquisitionTaskParameters(typing.Protocol):
+    pass
+
+
+@dataclasses.dataclass
+class AcquisitionParameters:
+    """Internal class describing an acquisition."""
+    frame_parameters: FrameParameters
+    acquisition_task_parameters: AcquisitionTaskParameters
+
+
 class HardwareSource(typing.Protocol):
 
     # methods
@@ -902,7 +919,7 @@ class HardwareSource(typing.Protocol):
     abort_event: Event.Event
     acquisition_state_changed_event: Event.Event
 
-    def add_data_channel(self, channel_id: typing.Optional[str] = None, name: typing.Optional[str] = None) -> None: ...
+    def add_data_channel(self, channel_id: typing.Optional[str] = None, name: typing.Optional[str] = None, *, is_context: bool = False) -> None: ...
     def add_channel_processor(self, channel_index: int, processor: SumProcessor) -> None: ...
     def get_frame_parameters_from_dict(self, d: typing.Mapping[str, typing.Any]) -> FrameParameters: ...
     def set_channel_enabled(self, channel_index: int, enabled: bool) -> None: ...
@@ -1097,21 +1114,20 @@ class ConcreteHardwareSource(Observable.Observable, HardwareSource):
         for data_element in data_elements:
             assert data_element is not None
             channel_id = data_element.get("channel_id")
-            # find channel_index for channel_id
-            channel_index = next((data_channel.index for data_channel in self.__data_channels if data_channel.channel_id == channel_id), 0)
-            data_and_metadata = ImportExportManager.convert_data_element_to_data_and_metadata(data_element)
-            # data_and_metadata data may still point to low level code memory at this point.
-            channel_state = data_element.get("state", "complete" if not is_error else "error")
-            if channel_state != "complete" and is_stopping and not is_error:
-                channel_state = "marked"
-            data_shape = data_element.get("data_shape")
-            dest_sub_area = data_element.get("dest_sub_area")
-            sub_area = data_element.get("sub_area")
-            data_channel = self.__data_channels[channel_index]
-            # data_channel.update will make a copy of the data_and_metadata
-            data_channel.update(data_and_metadata, channel_state, data_shape, dest_sub_area, sub_area, view_id)
-            data_channels.append(data_channel)
-            xdatas.append(data_channel.data_and_metadata)
+            data_channel = next(filter(lambda dc: dc.channel_id == channel_id, self.__data_channels), None)
+            if data_channel:
+                data_and_metadata = ImportExportManager.convert_data_element_to_data_and_metadata(data_element)
+                # data_and_metadata data may still point to low level code memory at this point.
+                channel_state = data_element.get("state", "complete" if not is_error else "error")
+                if channel_state != "complete" and is_stopping and not is_error:
+                    channel_state = "marked"
+                data_shape = data_element.get("data_shape")
+                dest_sub_area = data_element.get("dest_sub_area")
+                sub_area = data_element.get("sub_area")
+                # data_channel.update will make a copy of the data_and_metadata
+                data_channel.update(data_and_metadata, channel_state, data_shape, dest_sub_area, sub_area, view_id)
+                data_channels.append(data_channel)
+                xdatas.append(data_channel.data_and_metadata)
         # update channel buffers with processors
         for data_channel in self.__data_channels:
             src_channel_index = data_channel.src_channel_index
@@ -1247,7 +1263,8 @@ class ConcreteHardwareSource(Observable.Observable, HardwareSource):
     # thread safe
     def start_recording(self, sync_timeout: typing.Optional[float] = None, finished_callback_fn: typing.Optional[_FinishedCallbackType] = None, *, frame_parameters: typing.Optional[FrameParameters] = None, **kwargs: typing.Any) -> None:
         if not self.is_recording:
-            record_task = self._create_acquisition_record_task(frame_parameters=frame_parameters)
+            # pass kwargs for acquisition_task_parameters until things are cleaned up universally
+            record_task = self._create_acquisition_record_task(frame_parameters=frame_parameters, **kwargs)
             old_finished_callback_fn = record_task.finished_callback_fn
 
             def finished(data_promises: typing.Sequence[DataAndMetadataPromise]) -> None:
@@ -1343,8 +1360,8 @@ class ConcreteHardwareSource(Observable.Observable, HardwareSource):
     def __data_channel_state_changed(self, data_channel: DataChannel) -> None:
         self.data_channel_state_changed_event.fire(data_channel)
 
-    def add_data_channel(self, channel_id: typing.Optional[str] = None, name: typing.Optional[str] = None) -> None:
-        data_channel = DataChannel(self, len(self.__data_channels), channel_id, name)
+    def add_data_channel(self, channel_id: typing.Optional[str] = None, name: typing.Optional[str] = None, *, is_context: bool = False) -> None:
+        data_channel = DataChannel(self, len(self.__data_channels), channel_id, name, is_context=is_context)
         self.__data_channels.append(data_channel)
         self.__data_channel_state_changed_listeners.append(data_channel.data_channel_state_changed_event.listen(weak_partial(ConcreteHardwareSource.__data_channel_state_changed, self, data_channel)))
 
@@ -1440,6 +1457,12 @@ class DelegateHardwareSource(ConcreteHardwareSource):
     def _create_acquisition_view_task(self) -> DelegateAcquisitionTask:
         return DelegateAcquisitionTask(self.__delegate, self.hardware_source_id, self.display_name)
 
+    def set_record_frame_parameters(self, frame_parameters: FrameParameters) -> None:
+        raise NotImplementedError()
+
+    def get_record_frame_parameters(self) -> FrameParameters:
+        raise NotImplementedError()
+
 
 class SumProcessor(Observable.Observable):
     def __init__(self, bounds: Geometry.FloatRect, processor_id: typing.Optional[str] = None, label: typing.Optional[str] = None) -> None:
@@ -1599,7 +1622,7 @@ class ViewTask:
 class RecordTask:
     """Run acquisition in a thread and record the result."""
 
-    def __init__(self, hardware_source: HardwareSource, frame_parameters: FrameParameters) -> None:
+    def __init__(self, hardware_source: HardwareSource, acquisition_parameters: AcquisitionParameters) -> None:
         self.__hardware_source = hardware_source
 
         assert not self.__hardware_source.is_recording
@@ -1611,8 +1634,9 @@ class RecordTask:
         self.__recording_started = threading.Event()
 
         def record_thread() -> None:
-            self.__hardware_source.set_record_frame_parameters(frame_parameters)
-            self.__hardware_source.start_recording()
+            self.__hardware_source.set_record_frame_parameters(acquisition_parameters.frame_parameters)
+            # pass the acquisition_task_parameters, so they can get to _create_acquisition_record_task
+            self.__hardware_source.start_recording(acquisition_task_parameters=acquisition_parameters.acquisition_task_parameters)
             self.__recording_started.set()
             self.__data_and_metadata_list = self.__hardware_source.get_next_xdatas_to_finish()
             self.__hardware_source.stop_recording(sync_timeout=3.0)
