@@ -4,6 +4,7 @@ from __future__ import annotations
 import abc
 import asyncio
 import copy
+import dataclasses
 import enum
 import functools
 import gettext
@@ -392,10 +393,12 @@ class STEMController(Observable.Observable):
         self.scan_context_data_items_changed_event.fire()
 
     def _update_scan_channel_map(self, channel_map: typing.Mapping[str, DataItem.DataItem]) -> None:
-        old_scan_context_channel_map = copy.copy(self.__scan_context_channel_map)
+        # old_scan_context_channel_map = copy.copy(self.__scan_context_channel_map)
         self.__scan_context_channel_map.update(channel_map)
-        if old_scan_context_channel_map != self.__scan_context_channel_map:
-            self.scan_context_data_items_changed_event.fire()
+        # always fire this even if the map is unchanged; properties (channel enabled) which affect
+        # downstream filtering might have changed.
+        # if old_scan_context_channel_map != self.__scan_context_channel_map:
+        self.scan_context_data_items_changed_event.fire()
 
     @property
     def scan_context(self) -> ScanContext:
@@ -636,27 +639,45 @@ class AbstractGraphicSetHandler(abc.ABC):
         ...
 
 
+@dataclasses.dataclass
+class GraphicTracker:
+    display_item: DisplayItem.DisplayItem
+    graphic: Graphics.Graphic
+    graphic_property_changed_listener: Event.EventListener
+    remove_region_graphic_event_listener: Event.EventListener
+    display_about_to_be_removed_listener: Event.EventListener
+
+    def close(self) -> None:
+        self.display_item = typing.cast(typing.Any, None)
+        self.graphic = typing.cast(typing.Any, None)
+        self.graphic_property_changed_listener.close()
+        self.graphic_property_changed_listener = typing.cast(typing.Any, None)
+        self.remove_region_graphic_event_listener.close()
+        self.remove_region_graphic_event_listener = typing.cast(typing.Any, None)
+        self.display_about_to_be_removed_listener.close()
+        self.display_about_to_be_removed_listener = typing.cast(typing.Any, None)
+
+
 class GraphicSetController:
 
     def __init__(self, handler: AbstractGraphicSetHandler):
-        self.__graphic_trackers : typing.List[typing.Tuple[Graphics.Graphic, Event.EventListener, Event.EventListener, Event.EventListener]] = list()
+        self.__graphic_trackers : typing.List[GraphicTracker] = list()
         self.__handler = handler
 
     def close(self) -> None:
-        for _, graphic_property_changed_listener, remove_region_graphic_event_listener, display_about_to_be_removed_listener in self.__graphic_trackers:
-            graphic_property_changed_listener.close()
-            remove_region_graphic_event_listener.close()
-            display_about_to_be_removed_listener.close()
+        for graphic_tracker in self.__graphic_trackers:
+            graphic_tracker.close()
         self.__graphic_trackers = list()
 
     @property
     def graphics(self) -> typing.Sequence[Graphics.Graphic]:
-        return [t[0] for t in self.__graphic_trackers]
+        return [graphic_tracker.graphic for graphic_tracker in self.__graphic_trackers]
 
     def synchronize_graphics(self, display_items: typing.Sequence[DisplayItem.DisplayItem]) -> None:
         # create graphics for each scan data item if it doesn't exist
-        if not self.__graphic_trackers:
-            for display_item in display_items:
+        display_items_with_graphic_trackers = {graphic_tracker.display_item for graphic_tracker in self.__graphic_trackers}
+        for display_item in display_items:
+            if display_item not in display_items_with_graphic_trackers:
                 graphic = self.__handler._create_graphic()
 
                 def graphic_property_changed(graphic: Graphics.Graphic, name: str) -> None:
@@ -673,8 +694,18 @@ class GraphicSetController:
 
                 remove_region_graphic_event_listener = graphic.about_to_be_removed_event.listen(functools.partial(graphic_removed, graphic))
                 display_about_to_be_removed_listener = display_item.about_to_be_removed_event.listen(functools.partial(display_removed, graphic))
-                self.__graphic_trackers.append((graphic, graphic_property_changed_listener, remove_region_graphic_event_listener, display_about_to_be_removed_listener))
+                self.__graphic_trackers.append(GraphicTracker(display_item, graphic, graphic_property_changed_listener, remove_region_graphic_event_listener, display_about_to_be_removed_listener))
                 display_item.add_graphic(graphic)
+        # remove graphics that are no longer valid. note: copy list because it may change during iteration.
+        for graphic_tracker in list(self.__graphic_trackers):
+            graphic_tracker_display_item = graphic_tracker.display_item
+            graphic_tracker_graphic = graphic_tracker.graphic
+            if graphic_tracker_display_item not in display_items:
+                # remove/close the graphic tracker associated with the graphic. this ensures that when the
+                # graphic is removed next it will not remove the graphics on the other context items.
+                self.__remove_one_graphic(graphic_tracker_graphic)
+                # this will update __graphic_trackers
+                graphic_tracker_display_item.remove_graphic(graphic_tracker_graphic).close()
         # apply new value to any existing graphics
         for graphic in self.graphics:
             self.__handler._update_graphic(graphic)
@@ -684,27 +715,20 @@ class GraphicSetController:
         # are out of scope when the graphic is removed from its container via `remove_graphic`.
         # this ensures the listeners are inactive when `remove_graphic` is called.
         graphics = list()
-        for graphic, graphic_property_changed_listener, remove_region_graphic_event_listener, display_about_to_be_removed_listener in self.__graphic_trackers:
-            graphic_property_changed_listener.close()
-            remove_region_graphic_event_listener.close()
-            display_about_to_be_removed_listener.close()
-            graphics.append(graphic)
-            del graphic_property_changed_listener
-            del remove_region_graphic_event_listener
-            del display_about_to_be_removed_listener
+        for graphic_tracker in self.__graphic_trackers:
+            graphics.append(graphic_tracker.graphic)
+            graphic_tracker.close()
         self.__graphic_trackers = list()
         for graphic in graphics:
             graphic.display_item.remove_graphic(graphic).close()
 
     def __remove_one_graphic(self, graphic_to_remove: Graphics.Graphic) -> None:
-        graphic_trackers = list()
-        for graphic, graphic_property_changed_listener, remove_region_graphic_event_listener, display_about_to_be_removed_listener in self.__graphic_trackers:
-            if graphic_to_remove != graphic:
-                graphic_trackers.append((graphic, graphic_property_changed_listener, remove_region_graphic_event_listener, display_about_to_be_removed_listener))
+        graphic_trackers: typing.List[GraphicTracker] = list()
+        for graphic_tracker in self.__graphic_trackers:
+            if graphic_to_remove != graphic_tracker.graphic:
+                graphic_trackers.append(graphic_tracker)
             else:
-                graphic_property_changed_listener.close()
-                remove_region_graphic_event_listener.close()
-                display_about_to_be_removed_listener.close()
+                graphic_tracker.close()
         self.__graphic_trackers = graphic_trackers
 
 
@@ -811,7 +835,7 @@ def make_scan_display_item_list_model(document_model: DocumentModel.DocumentMode
     def is_scan_context_display_item(display_item: DisplayItem.DisplayItem) -> bool:
         scan_controller = stem_controller.scan_controller
         if scan_controller:
-            context_data_channels = scan_controller.get_context_data_channels()
+            context_data_channels = scan_controller.get_enabled_context_data_channels()
             for data_channel in context_data_channels:
                 data_item_channel_reference = document_model.get_data_item_channel_reference(scan_controller.hardware_source_id, data_channel.channel_id)
                 if data_item_channel_reference and data_item_channel_reference.display_item == display_item:
@@ -859,6 +883,7 @@ class ProbeView(EventLoopMonitor, AbstractGraphicSetHandler, DocumentModel.Abstr
         self.__document_model = document_model
         self.__scan_display_items_model = make_scan_display_item_list_model(document_model, stem_controller, self._call_soon_threadsafe)
         self.__display_item_inserted_event_listener = self.__scan_display_items_model.item_inserted_event.listen(ReferenceCounting.weak_partial(ProbeView.__display_item_inserted, self))
+        self.__display_item_removed_event_listener = self.__scan_display_items_model.item_removed_event.listen(ReferenceCounting.weak_partial(ProbeView.__display_item_removed, self))
         self.__project_loaded_event_listener = document_model.project_loaded_event.listen(ReferenceCounting.weak_partial(ProbeView.__refilter_scan_display_items, self))
         self.__graphic_set = GraphicSetController(self)
         # note: these property changed listeners can all possibly be fired from a thread.
@@ -881,6 +906,7 @@ class ProbeView(EventLoopMonitor, AbstractGraphicSetHandler, DocumentModel.Abstr
         self.__document_model = typing.cast(typing.Any, None)
         self.__stem_controller = typing.cast(typing.Any, None)
         self.__display_item_inserted_event_listener = typing.cast(typing.Any, None)
+        self.__display_item_removed_event_listener = typing.cast(typing.Any, None)
         self.__project_loaded_event_listener = typing.cast(typing.Any, None)
         self.__class__.count -= 1
 
@@ -911,6 +937,11 @@ class ProbeView(EventLoopMonitor, AbstractGraphicSetHandler, DocumentModel.Abstr
             stem_controller = self.__stem_controller
             self.__update_probe_state(stem_controller.probe_state, stem_controller.probe_position)
 
+    def __display_item_removed(self, name: str, item: DisplayItem.DisplayItem, index: int) -> None:
+        if name == "display_items":
+            stem_controller = self.__stem_controller
+            self.__update_probe_state(stem_controller.probe_state, stem_controller.probe_position)
+
     # implement methods for the graphic set handler
 
     def _graphic_removed(self, probe_graphic: Graphics.Graphic) -> None:
@@ -955,6 +986,7 @@ class SubscanView(EventLoopMonitor, AbstractGraphicSetHandler, DocumentModel.Abs
         self.__document_model = document_model
         self.__scan_display_items_model = make_scan_display_item_list_model(document_model, stem_controller, self._call_soon_threadsafe)
         self.__display_item_inserted_event_listener = self.__scan_display_items_model.item_inserted_event.listen(ReferenceCounting.weak_partial(SubscanView.__display_item_inserted, self))
+        self.__display_item_removed_event_listener = self.__scan_display_items_model.item_removed_event.listen(ReferenceCounting.weak_partial(SubscanView.__display_item_removed, self))
         self.__project_loaded_event_listener = document_model.project_loaded_event.listen(ReferenceCounting.weak_partial(SubscanView.__refilter_scan_display_items, self))
         self.__graphic_set = GraphicSetController(self)
         # note: these property changed listeners can all possibly be fired from a thread.
@@ -974,6 +1006,7 @@ class SubscanView(EventLoopMonitor, AbstractGraphicSetHandler, DocumentModel.Abs
         self.__document_model = typing.cast(typing.Any, None)
         self.__stem_controller = typing.cast(typing.Any, None)
         self.__display_item_inserted_event_listener = typing.cast(typing.Any, None)
+        self.__display_item_removed_event_listener = typing.cast(typing.Any, None)
         self.__project_loaded_event_listener = typing.cast(typing.Any, None)
         self.__class__.count -= 1
 
@@ -1012,6 +1045,10 @@ class SubscanView(EventLoopMonitor, AbstractGraphicSetHandler, DocumentModel.Abs
         if name == "display_items":
             self.__update_subscan_region()
 
+    def __display_item_removed(self, name: str, item: DisplayItem.DisplayItem, index: int) -> None:
+        if name == "display_items":
+            self.__update_subscan_region()
+
     # implement methods for the graphic set handler
 
     def _graphic_removed(self, subscan_graphic: Graphics.Graphic) -> None:
@@ -1063,6 +1100,7 @@ class LineScanView(EventLoopMonitor, AbstractGraphicSetHandler, DocumentModel.Ab
         self.__document_model = document_model
         self.__scan_display_items_model = make_scan_display_item_list_model(document_model, stem_controller, self._call_soon_threadsafe)
         self.__display_item_inserted_event_listener = self.__scan_display_items_model.item_inserted_event.listen(ReferenceCounting.weak_partial(LineScanView.__display_item_inserted, self))
+        self.__display_item_removed_event_listener = self.__scan_display_items_model.item_removed_event.listen(ReferenceCounting.weak_partial(LineScanView.__display_item_removed, self))
         self.__project_loaded_event_listener = document_model.project_loaded_event.listen(ReferenceCounting.weak_partial(LineScanView.__refilter_scan_display_items, self))
         self.__graphic_set = GraphicSetController(self)
         # note: these property changed listeners can all possibly be fired from a thread.
@@ -1081,6 +1119,7 @@ class LineScanView(EventLoopMonitor, AbstractGraphicSetHandler, DocumentModel.Ab
         self.__document_model = typing.cast(typing.Any, None)
         self.__stem_controller = typing.cast(typing.Any, None)
         self.__display_item_inserted_event_listener = typing.cast(typing.Any, None)
+        self.__display_item_removed_event_listener = typing.cast(typing.Any, None)
         self.__project_loaded_event_listener = typing.cast(typing.Any, None)
         self.__class__.count -= 1
 
@@ -1112,6 +1151,10 @@ class LineScanView(EventLoopMonitor, AbstractGraphicSetHandler, DocumentModel.Ab
         if name == "display_items":
             self.__update_line_scan_vector()
 
+    def __display_item_removed(self, name: str, item: DisplayItem.DisplayItem, index: int) -> None:
+        if name == "display_items":
+            self.__update_line_scan_vector()
+
     # implement methods for the graphic set handler
 
     def _graphic_removed(self, line_scan_graphic: Graphics.Graphic) -> None:
@@ -1160,6 +1203,7 @@ class DriftView(EventLoopMonitor):
         self.__document_model = document_model
         self.__scan_display_items_model = make_scan_display_item_list_model(document_model, stem_controller, self._call_soon_threadsafe)
         self.__display_item_inserted_event_listener = self.__scan_display_items_model.item_inserted_event.listen(ReferenceCounting.weak_partial(DriftView.__display_item_inserted, self))
+        self.__display_item_removed_event_listener = self.__scan_display_items_model.item_removed_event.listen(ReferenceCounting.weak_partial(DriftView.__display_item_removed, self))
         self.__project_loaded_event_listener = document_model.project_loaded_event.listen(ReferenceCounting.weak_partial(DriftView.__clean, self))
         self.__graphic_display_item : typing.Optional[DisplayItem.DisplayItem] = None
         self.__graphic : typing.Optional[Graphics.RectangleGraphic] = None
@@ -1188,6 +1232,7 @@ class DriftView(EventLoopMonitor):
         self.__document_model = typing.cast(typing.Any, None)
         self.__stem_controller = typing.cast(typing.Any, None)
         self.__display_item_inserted_event_listener = typing.cast(typing.Any, None)
+        self.__display_item_removed_event_listener = typing.cast(typing.Any, None)
         self.__project_loaded_event_listener = typing.cast(typing.Any, None)
         self.__class__.count -= 1
 
@@ -1299,6 +1344,10 @@ class DriftView(EventLoopMonitor):
         if name == "display_items":
             self.__update_drift_region()
 
+    def __display_item_removed(self, name: str, item: DisplayItem.DisplayItem, index: int) -> None:
+        if name == "display_items":
+            self.__update_drift_region()
+
 
 class ScanContextController:
     """Manage probe view, subscan, and drift area for each instrument (STEMController) that gets registered."""
